# classes/asterisk.pp

class astrad002::asterisk {
	
	file {"/usr/local/bin/bash":
		ensure	=> present,
		source	=> "/bin/bash"
	}

	file {"/usr/local/bin/wget":
		ensure  => present,
		source  => "/usr/bin/wget"
	}

	exec { "asterisk restart":
		command	    => "/etc/init.d/astrad restart",
		refreshonly => true,
                require => File["/etc/init.d/"],
                notify=> Exec['Restart Alert@']
	}

       exec{ "Restart Alert@":
                command => "echo 'Puppet master has caused Astrad restarting.\nServer = $fqdn' | mailx -s 'Astrad  Restart' alerts@unappel.ch",
                refreshonly => true
        }


	service { "asterisk":
		ensure => running,
		enable => true,
		require=> Package['asterisk'],
	}

	package { asterisk:		
                ensure   => installed,
                require => Exec['aptitude update']
        }


	exec { "cron restart":
	        path        => "/etc/init.d/",
        	refreshonly => true
	}

	service { "cron":
        	ensure => running,
	        enable => true,
	}


	#file {"/etc/asterisk/default-confs":
	#	ensure	=> directory,
	#	require => Package["asterisk"],
        #        #efore  => Exec['Backup default config files']
	#}


	exec { "Backup default config files":
		#refreshonly	=> true,
                unless => "ls -d /etc/asterisk/default-confs > /dev/null 2>&1",
		command => "mkdir /etc/asterisk/default-confs;mv /etc/asterisk/*.* /etc/asterisk/default-confs/",
		#cwd => "/etc/asterisk",
                #require => [Package['asterisk'],File['/etc/asterisk/default-confs']]
                #require => File['/etc/asterisk/default-confs']
                require => Package["asterisk"]
	}

	include perl	
	define packagesCPAN {
		perl::installCPAN {    ["YAML", 
					"Config::IniFiles", 
					"Crypt::CBC", 
					"Crypt::DES", 
					"Authen::Radius", 
					"Crypt::Rijndael", 
					"Digest::MD5", 
					"Asterisk::Manager", 
					"List::Util", 
					"Sys::Syslog", 
					"Date::Manip",
					"Asterisk::AGI"]:
		}
	}
	
	packagesCPAN{"asterisk":
		require	=> Package["asterisk"]
	}
	
	# Get the additional dependancy
	file { "/tmp/asterisk-perl-1.01.tar.gz":
		ensure => file,
		source => "puppet:///$module_name/tar/asterisk-perl-1.01.tar.gz",
		notify =>  Exec ["Extract Asterisk dependancy"],
	}
	
	exec { "Extract Asterisk dependancy":
		refreshonly => true,
		command => "tar xzf asterisk-perl-1.01.tar.gz",
		cwd	=> "/tmp",
		creates => "/tmp/asterisk-perl-1.01",
	}
	# Install dependancy
	exec { "perl Makefile.PL;make all;make install":
		subscribe => Exec[ "Extract Asterisk dependancy"],
		refreshonly => true,
		cwd	=> "/tmp/asterisk-perl-1.01",
		path    => "/usr/bin:/usr/sbin:/bin:/sbin",
		require	=> PackagesCPAN["asterisk"]
	}


	group{"asterisk":
		ensure	=> present,
		require	=> Package['asterisk']
	}

	# configure asterisk
	file{"/etc/asterisk":
		ensure	=> directory,
		owner   => asterisk,
		group	=> asterisk,
		mode    => 644,
		recurse => true,
                replace => false,
		source	=> "puppet:///$module_name/asterisk",
		notify  => Exec['asterisk restart'],
                require  => [Exec ['Backup default config files'],Group["asterisk"],Service["asterisk"]] 
                }

	# Asterisk conf files
	# using templates	
	
	file{"/etc/asterisk/asterisk.conf":
		ensure	=> file,
		owner   => asterisk,
		group   => asterisk,
		mode	=> 644,
		replace => true,
		content => template("$module_name/asterisk.conf.erb"),
		notify  => Exec['asterisk restart'],
                require  => File["/etc/asterisk"]
	}

	file{"/etc/asterisk/ext-radius.conf":
		ensure	=> file,
		owner   => asterisk,
		group   => asterisk,
		mode    => 644,
		replace => true,
		content => template("$module_name/ext-radius.conf.erb"),
		notify  => Exec['asterisk restart'],
                require  => File["/etc/asterisk"]
 	}

	file{"/etc/asterisk/manager.conf":
		ensure	=> file,
		owner   => asterisk,
		group   => asterisk,
		mode    => 644,
		replace => true,
		content => template("$module_name/manager.conf.erb"),
		notify	=> Exec['asterisk restart'],
                require  => File["/etc/asterisk"]
	}
	
	file { "/etc/astrad-V2":
		ensure => directory
	}
	
	file{"/etc/astrad-V2/script":
		ensure  => directory,
		owner	=> root,
		group	=> root,
		mode	=> 755,
		recurse	=> true,
		replace	=> true,
		source	=> "puppet:///$module_name/script",
		require => File["/etc/astrad-V2"]
	}

	file{"/etc/astrad-V2/cron":
		ensure  => directory,
		owner	=> root,
		group	=> root,
		mode	=> 755,
		recurse	=> true,
		replace	=> true,
		source	=> "puppet:///$module_name/cron",
		require => File["/etc/astrad-V2"]
	}
	
	file { "/etc/astrad-V2/config":
		ensure => directory,
		require => File["/etc/astrad-V2"]
	}
	
	file{"/etc/astrad-V2/config/switzer.conf":
		ensure	=> file,
		owner   => root,
		group   => root,
		mode    => 644,
		replace => true,
		content => template("$module_name/switzer.conf.erb"),
		require => File["/etc/astrad-V2/config"],
		notify  => Exec['asterisk restart']
	}

	file{"/etc/astrad-V2/script/ast-get-peer/ast-get-peer.pl":
		owner	=> root,
		group	=> root,
		mode	=> 755,
                require => File["/etc/astrad-V2/script"],
		content => template("$module_name/ast-get-peer.pl.erb")
	}

	file{"/etc/astrad-V2/script/ast-get-peer/KeyAstr":
		owner	=> root,
		group	=> root,
		mode	=> 755,
                require => File["/etc/astrad-V2/script"],
		content => template("$module_name/KeyAstr.erb")
	}
	
	file{"/etc/astrad-V2/script/ast-registred-sip/cron.sh":
		owner	=> root,
		group	=> root,
		mode	=> 755,
                require => File["/etc/astrad-V2/script"],
		content => template("$module_name/cron.sh.erb")
	}

	file{"/etc/logrotate.d/asterisk":
		ensure	=> file,
		owner   => root,
		group   => root,
		mode    => 755,
		replace => true,
		content => template("$module_name/asterisk.erb")
	}

        file{"/usr/share/asterisk/agi-bin":
                ensure  => directory,
                recurse => true,
                replace => true,
                require => Package['asterisk']
        }
	
	file{"/usr/share/asterisk/agi-bin/agi-rad-auth.pl":
		ensure	=> file,
		owner	=> root,
		group	=> root,
		mode	=> 755,
		recurse	=> true,
		replace	=> true,
		source	=> "puppet:///$module_name/script/agi-rad-auth.pl",
		require => [File["/etc/astrad-V2/script"],File["/usr/share/asterisk/agi-bin"]]
	}

	file{"/var/log/asterisk/cdr-csv-old":
		ensure	=> directory,
		recurse	=> true,
		replace	=> true,
		require	=> Package['asterisk']
	}

	# Add codecs
	
	file{"/usr/lib/asterisk/modules/codec_g723-ast14-icc-glibc-x86_64-pentium4.so":
		ensure	=> file,
		source	=> "puppet:///$module_name/codec/codec_g723-ast14-icc-glibc-x86_64-pentium4.so",
		notify	=> Exec["asterisk restart"],
		require => Package['asterisk']
	}
		

	file{"/usr/lib/asterisk/modules/codec_g729-ast14-icc-glibc-x86_64-pentium4.so":
		ensure	=> file,
		source	=> "puppet:///$module_name/codec/codec_g729-ast14-icc-glibc-x86_64-pentium4.so",
		notify  => Exec["asterisk restart"],
		require => Package['asterisk']
	}

	# Add sounds	
	file{"/usr/share/asterisk/sounds/":
		ensure  => directory,
		recurse	=> true,
		mode    => 644,
		source  => "puppet:///$module_name/sounds",
		require	=> Package["asterisk"]
	}

	file{"/etc/init.d/":
		ensure  => directory,
		recurse	=> true,
                mode    => 755,
		replace	=> true,
		source  => "puppet:///$module_name/init.d",
		require	=> Package["asterisk"]
	}

	file{"/var/sipenv-$ipaddress":
		ensure => directory,
	}
	
	file{"/var/sipenv-$ipaddress/log":
		ensure	=> directory,
		require	=> File["/var/sipenv-$ipaddress"]
	}
	

	define load_mysql_table($db="asterisk", $file, $path = "/root", $module=$module_name, $source){
		
		exec{"mysql -uroot -p$mysql_root_pass < $path/$file":
			refreshonly => true,
			#unless	=> "mysql -uroot -p$mysql_root_pass -e \"show tables from $db like '$name' \" 2> /dev/null",
			require	=> [ Service['mysql'], Exec["Set MySQL root password"], File["$path/$file"]]
		}

		file{"$path/$file":
			ensure	=> file,
			replace	=> true,
			source	=> "puppet:///$module/$source",
			notify  => Exec["mysql -uroot -p$mysql_root_pass < $path/$file"]
		}
		
	}	

	load_mysql_table{"radius_packets":
		file	=> "radius_packets.sql",
		source	=> "mysql/asterisk.sql"
	}

	exec{"update-rc.d astrad defaults;update-rc.d -f asterisk remove":
		refreshonly => true,
		subscribe => File['/etc/init.d/']
	}
	
	# define logs
        exec { "rsyslog restart":
                path        => "/etc/init.d/",
                refreshonly => true
        }

	line{"asterisk.log":
		line => "local0.*                        -/var/log/asterisk.log",
		file => "/etc/rsyslog.conf",
		ensure => present,
                notify  => Exec["rsyslog restart"]
	}

	file{"/etc/cron.d/ASTRAD":
		ensure	=> file,
		replace	=> true,
		source	=> "puppet:///$module_name/cron/ASTRAD",
		notify  => Exec["cron restart"],
	}
}

